function setupBiome_savanna()
{
	g_Gaia.mainHuntableAnimal = pickRandom([
		"gaia/fauna_wildebeest",
		"gaia/fauna_zebra",
		"gaia/fauna_giraffe",
		"gaia/fauna_gazelle"
	]);
}
